@@ -2,12 +2,14 @@ use crate::{util, Cell, Ordering, Rc, Record, SaveOp, SortedFile, DB};
 
 /// =4. Number of fragment types.
 pub const NFT: usize = 4;
-/// =28. Min fragment size.
-pub const MINF: usize = 28;
+/// =40. Min fragment size.
+pub const MINF: usize = 40;
+/// =29. Fragment increment.
+pub const FI: usize = 29;
 
 /// Total bytes used taking into account all overhead ( 3 + 1 + 8 = 12 bytes, per fragment ).
 fn total(len: usize, ft: usize) -> usize {
-    let bpf = 32 * ft + MINF;
+    let bpf = FI * ft + MINF;
     let nf = (len + bpf - 1) / bpf;
     nf * (bpf + 12)
 }
@@ -23,22 +25,22 @@ pub fn fragment_type(len: usize) -> usize {
             result = ft;
         }
     }
-    // println!("fragment_type for len={} = {}", len, result );
     result
 }
 
 /// Storage of variable size values.
 pub struct ByteStorage {
-    pub(crate) file: Rc<SortedFile>,
+    ///
+    pub file: Rc<SortedFile>,
     id_gen: Cell<u64>,
-    /// Bytes per fragment. One of 28, 60, 92, 124.
+    /// Bytes per fragment. One of 40, 69, 98, 127.
     bpf: usize,
 }
 
 impl ByteStorage {
-    pub(crate) fn new(root_page: u64, ft: usize) -> Self {
-        // println!("ByteStorage::new root={} ft={}", root_page, ft );
-        let bpf = 32 * ft + MINF;
+    /// Construct new ByteStorage with specified root page and fragment type.
+    pub fn new(root_page: u64, ft: usize) -> Self {
+        let bpf = FI * ft + MINF;
         let file = Rc::new(SortedFile::new(9 + bpf, 8, root_page));
         ByteStorage {
             file,
@@ -47,7 +49,8 @@ impl ByteStorage {
         }
     }
 
-    pub(crate) fn get_id(&self, db: &DB) -> u64 {
+    /// Get fragment Id value.
+    fn get_id(&self, db: &DB) -> u64 {
         let mut result = self.id_gen.get();
         if result == u64::MAX {
             result = 0;
@@ -62,16 +65,17 @@ impl ByteStorage {
         result
     }
 
-    pub(crate) fn save(&self, db: &DB, op: SaveOp) {
+    /// Save to underlying file.
+    pub fn save(&self, db: &DB, op: SaveOp) {
         self.file.save(db, op);
     }
 
-    pub(crate) fn encode(&self, db: &DB, bytes: &[u8]) -> u64 {
+    /// Encode bytes.
+    pub fn encode(&self, db: &DB, bytes: &[u8]) -> u64 {
         let result = self.get_id(db);
         let mut r = Fragment::new(0, self.bpf);
         let n = bytes.len();
         let mut done = 0;
-        let mut _frags = 0;
         loop {
             r.id = self.id_gen.get();
             self.id_gen.set(r.id + 1);
@@ -82,10 +86,8 @@ impl ByteStorage {
             } else {
                 r.len = 1 + ((len as u8) << 1);
             }
-            // for i in 0..len { r.bytes[ i ] = bytes[ done + i ]; }
             r.bytes[..len].copy_from_slice(&bytes[done..(len + done)]);
             done += len;
-            _frags += 1;
             self.file.insert(db, &r);
             if done == n {
                 break;
@@ -94,8 +96,9 @@ impl ByteStorage {
         result
     }
 
-    pub(crate) fn decode(&self, db: &DB, mut id: u64, inline: usize) -> Vec<u8> {
-        let mut result = vec![0_u8; inline]; // inline bytes will be filled in from inline data.
+    /// Decode bytes, inline bytes are reserved.
+    pub fn decode(&self, db: &DB, mut id: u64, inline: usize) -> Vec<u8> {
+        let mut result = vec![0_u8; inline];
         let start = Fragment::new(id, self.bpf);
         for (pp, off) in self.file.asc(db, Box::new(start)) {
             let p = pp.borrow();
@@ -112,7 +115,8 @@ impl ByteStorage {
         result
     }
 
-    pub(crate) fn delcode(&self, db: &DB, id: u64) {
+    /// Delete a code.
+    pub fn delcode(&self, db: &DB, id: u64) {
         let start = Fragment::new(id, self.bpf);
         let mut n = 0;
         for (pp, off) in self.file.asc(db, Box::new(start)) {
@@ -132,14 +136,15 @@ impl ByteStorage {
         }
     }
 
+    /// Pack underlying file.
     #[cfg(feature = "pack")]
-    pub(crate) fn repack_file(&self, db: &DB) -> i64 {
+    pub fn repack_file(&self, db: &DB) -> i64 {
         let r = Fragment::new(0, self.bpf);
         self.file.repack(db, &r)
     }
 }
 
-/// Values are split into BPF size fragments.
+/// Values are split into fragments.
 struct Fragment {
     id: u64,
     /// Bit 0 encodes whether this is the last fragment.
