@@ -1,8 +1,8 @@
-use crate::{get_bytes, panic, util, CExp, CExpPtr, EvalEnv, FunctionPtr, Rc, Value};
+use crate::{get_bytes, panic, util, CExp, CExpPtr, EvalEnv, Function, Rc, Value};
 
 /// Function call.
 pub(crate) struct Call {
-    pub fp: FunctionPtr,
+    pub fp: Rc<Function>,
     pub pv: Vec<CExpPtr<Value>>,
 }
 
@@ -57,6 +57,30 @@ impl CExp<Value> for Concat {
     }
 }
 
+pub(crate) struct BinConcat {
+    pub c1: CExpPtr<Value>,
+    pub c2: CExpPtr<Value>,
+}
+
+impl CExp<Value> for BinConcat {
+    fn eval(&self, e: &mut EvalEnv, d: &[u8]) -> Value {
+        let mut b1 = self.c1.eval(e, d);
+        let b2 = self.c2.eval(e, d).bin();
+        // Append to existing bytes if not shared.
+        if let Value::RcBinary(b) = &mut b1 {
+            if let Some(mb) = Rc::get_mut(b) {
+                mb.extend_from_slice(&b2);
+                return b1;
+            }
+        }
+        let b1 = b1.bin();
+        let mut b = Vec::with_capacity(b1.len() + b2.len());
+        b.extend_from_slice(&b1);
+        b.extend_from_slice(&b2);
+        Value::RcBinary(Rc::new(b))
+    }
+}
+
 pub(crate) struct Or {
     pub c1: CExpPtr<bool>,
     pub c2: CExpPtr<bool>,
